# ♄ SATyrn: A SAT Solver Toolbox
![Travis (.org)](https://img.shields.io/travis/jeffrey-hokanson/satyrn.svg?style=flat-square)
![PyPI - License](https://img.shields.io/pypi/l/satyrn.svg?style=flat-square)
![PyPI](https://img.shields.io/pypi/v/satyrn.svg?style=flat-square)

An interface to SAT solvers.



## See Also

* [pycosat](https://github.com/ContinuumIO/pycosat)
* [pylgl](https://github.com/abfeldman/pylgl)

